@@ -1,5 +1,6 @@
-/*  Arg_parser - A POSIX/GNU command line argument parser. (C version)
-    Copyright (C) 2006, 2007, 2008, 2009, 2010 Antonio Diaz Diaz.
+/*  Arg_parser - POSIX/GNU command line argument parser. (C version)
+    Copyright (C) 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013
+    Antonio Diaz Diaz.
 
     This library is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -31,7 +32,7 @@
 #include "carg_parser.h"
 
 
-/* assure at least a minimum size for buffer `buf' */
+/* assure at least a minimum size for buffer 'buf' */
 static void * ap_resize_buffer( void * buf, const int min_size )
   {
   if( buf ) buf = realloc( buf, min_size );
@@ -45,7 +46,8 @@ static char push_back_record( struct Arg_parser * const ap,
   {
   const int len = strlen( argument );
   struct ap_Record *p;
-  void * tmp = ap_resize_buffer( ap->data, ( ap->data_size + 1 ) * sizeof (struct ap_Record) );
+  void * tmp = ap_resize_buffer( ap->data,
+                 ( ap->data_size + 1 ) * sizeof (struct ap_Record) );
   if( !tmp ) return 0;
   ap->data = (struct ap_Record *)tmp;
   p = &(ap->data[ap->data_size]);
@@ -86,16 +88,15 @@ static char parse_long_option( struct Arg_parser * const ap,
                                const struct ap_Option options[],
                                int * const argindp )
   {
-  unsigned int len;
-  int index = -1;
-  int i;
+  unsigned len;
+  int index = -1, i;
   char exact = 0, ambig = 0;
 
   for( len = 0; opt[len+2] && opt[len+2] != '='; ++len ) ;
 
   /* Test all long options for either exact match or abbreviated matches. */
   for( i = 0; options[i].code != 0; ++i )
-    if( options[i].name && !strncmp( options[i].name, &opt[2], len ) )
+    if( options[i].name && strncmp( options[i].name, &opt[2], len ) == 0 )
       {
       if( strlen( options[i].name ) == len )	/* Exact match found */
         { index = i; exact = 1; break; }
@@ -107,31 +108,31 @@ static char parse_long_option( struct Arg_parser * const ap,
 
   if( ambig && !exact )
     {
-    add_error( ap, "option `" ); add_error( ap, opt );
+    add_error( ap, "option '" ); add_error( ap, opt );
     add_error( ap, "' is ambiguous" );
     return 1;
     }
 
   if( index < 0 )		/* nothing found */
     {
-    add_error( ap, "unrecognized option `" ); add_error( ap, opt );
+    add_error( ap, "unrecognized option '" ); add_error( ap, opt );
     add_error( ap, "'" );
     return 1;
     }
 
   ++*argindp;
 
-  if( opt[len+2] )		/* `--<long_option>=<argument>' syntax */
+  if( opt[len+2] )		/* '--<long_option>=<argument>' syntax */
     {
     if( options[index].has_arg == ap_no )
       {
-      add_error( ap, "option `--" ); add_error( ap, options[index].name );
+      add_error( ap, "option '--" ); add_error( ap, options[index].name );
       add_error( ap, "' doesn't allow an argument" );
       return 1;
       }
     if( options[index].has_arg == ap_yes && !opt[len+3] )
       {
-      add_error( ap, "option `--" ); add_error( ap, options[index].name );
+      add_error( ap, "option '--" ); add_error( ap, options[index].name );
       add_error( ap, "' requires an argument" );
       return 1;
       }
@@ -142,7 +143,7 @@ static char parse_long_option( struct Arg_parser * const ap,
     {
     if( !arg || !arg[0] )
       {
-      add_error( ap, "option `--" ); add_error( ap, options[index].name );
+      add_error( ap, "option '--" ); add_error( ap, options[index].name );
       add_error( ap, "' requires an argument" );
       return 1;
       }
@@ -163,8 +164,7 @@ static char parse_short_option( struct Arg_parser * const ap,
 
   while( cind > 0 )
     {
-    int index = -1;
-    int i;
+    int index = -1, i;
     const unsigned char code = opt[cind];
     char code_str[2];
     code_str[0] = code; code_str[1] = 0;
